@@ -16,7 +16,7 @@ var customMocks = {
 }
 
 test("ignore-shrinkwrap: using the option", function (t) {
-  mr({port: common.port, mocks: customMocks}, function (s) {
+  mr({port: common.port, mocks: customMocks}, function (err, s) {
     s._server.on("request", function (req) {
       switch (req.url) {
         case "/shrinkwrap.js":
@@ -35,7 +35,7 @@ test("ignore-shrinkwrap: using the option", function (t) {
 })
 
 test("ignore-shrinkwrap: NOT using the option", function (t) {
-  mr({port: common.port, mocks: customMocks}, function (s) {
+  mr({port: common.port, mocks: customMocks}, function (err, s) {
     s._server.on("request", function (req) {
       switch (req.url) {
         case "/shrinkwrap.js":
