@@ -15,7 +15,7 @@ var EXEC_OPTS = {
 
 test("does not use unicode with --unicode false", function (t) {
   t.plan(5)
-  mr(common.port, function (s) {
+  mr({port : common.port}, function (er, s) {
     common.npm(["install", "--unicode", "false", "read"], EXEC_OPTS, function (err, code, stdout) {
       t.ifError(err, "install package read without unicode success")
       t.notOk(code, "npm install exited with code 0")
@@ -28,7 +28,7 @@ test("does not use unicode with --unicode false", function (t) {
 })
 
 test("cleanup", function (t) {
-  mr(common.port, function (s) {
+  mr({port : common.port}, function (er, s) {
     common.npm(["uninstall", "read"], EXEC_OPTS, function (err, code) {
       t.ifError(err, "uninstall read package success")
       t.notOk(code, "npm uninstall exited with code 0")
