@@ -13,7 +13,7 @@ mkdirp.sync(cache)
 
 test("includes devDependencies in outdated", function (t) {
   process.chdir(pkg)
-  mr(common.port, function (s) {
+  mr({port : common.port}, function (er, s) {
     npm.load({cache: cache, registry: common.registry}, function () {
       npm.outdated(function (er, d) {
         t.equal("1.5.1", d[0][3])
